===========
pyschelling
===========

A simple agent-based implementation of Schelling's segregation.

Usage:
------

To run the programme just open a console and type either

    pyschelling_console  

to run the simple command line version.

or

    pyschelling_gui  

to run a GTK+ version (requires pyGTK).
